@@ -24,7 +24,7 @@ class BaseTextureRepo(metaclass=ABCMeta):
 
 class BaseUserRepo(metaclass=ABCMeta):
     EMPTY_USER = User(
-        uuid="00000000000000000000000000000000",
+        uuid="8de67985-09c5-443b-be60-8fa552560e0e",
         login="empty",
         email="empty@example.com",
         synthetic=True
