@@ -16,3 +16,10 @@ class ErrorResponse(BaseModel):
 
     class Config:
         allow_mutation = False
+
+
+class TextureStatusResponse(BaseModel):
+    message: str
+
+    class Config:
+        allow_mutation = False
