@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import Optional, Dict, List, Tuple
+from typing import Optional, Dict, List
 
 from pydantic import UUID4
 from pydantic.main import BaseModel
@@ -40,7 +40,8 @@ class TextureUploadRequest(BaseModel):
 
 
 class TextureResponse(BaseModel):
-    textures: List[Tuple[TextureType, TextureItem]]
+    textures: Dict[TextureType, TextureItem]
 
     class Config:
         allow_mutation = False
+        use_enum_values = True
