@@ -10,11 +10,11 @@ class RequestsUserRepo(BaseUserRepo, RequestsRepo):
 
     def get_user(self, **kwargs: Dict[str, str]) -> Union[ErrorResponse, User]:
         payload = UserRequest(**kwargs)
-        return self.fetch(endpoint='/user/get', payload=payload, clazz=User)
+        return self.fetch(endpoint='/user/get/', payload=payload, clazz=User)
 
     def check_password(self, *, clean: str, uuid: str) -> Union[ErrorResponse, StatusResponse]:
         payload = PasswordRequest(uuid=uuid, password=clean)
-        return self.fetch(endpoint='/user/check_password', payload=payload, clazz=StatusResponse)
+        return self.fetch(endpoint='/user/check_password/', payload=payload, clazz=StatusResponse)
 
     def save_user(self, *, user: User) -> Union[ErrorResponse, User]:
-        return self.fetch(endpoint='/user/save', payload=user, clazz=User)
+        return self.fetch(endpoint='/user/save/', payload=user, clazz=User)
